@@ -234,6 +234,16 @@ class DjangoCreateMutationField(DjangoInputMutationField):
 
     """
 
+    def __init__(self, *args, **kwargs):
+        self.full_clean: bool = kwargs.pop("full_clean", True)
+        super().__init__(*args, **kwargs)
+
+    @property
+    def arguments(self) -> List[StrawberryArgument]:
+        # FIXME: We don't have a base_resolve in this case. Make sure StrawberryDjangoFieldFilters
+        # doesn't add a opk argument in here...
+        return [a for a in super().arguments if a.python_name == "input"]
+
     @async_safe
     def resolver(
         self,
@@ -244,7 +254,9 @@ class DjangoCreateMutationField(DjangoInputMutationField):
         kwargs: Dict[str, Any],
     ) -> Any:
         assert data is not None
-        return resolvers.create(info, self.model, resolvers.parse_input(info, vars(data)))
+        return resolvers.create(
+            info, self.model, resolvers.parse_input(info, vars(data)), full_clean=self.full_clean
+        )
 
 
 class DjangoUpdateMutationField(DjangoInputMutationField):
@@ -255,6 +267,16 @@ class DjangoUpdateMutationField(DjangoInputMutationField):
 
     """
 
+    def __init__(self, *args, **kwargs):
+        self.full_clean: bool = kwargs.pop("full_clean", True)
+        super().__init__(*args, **kwargs)
+
+    @property
+    def arguments(self) -> List[StrawberryArgument]:
+        # FIXME: We don't have a base_resolve in this case. Make sure StrawberryDjangoFieldFilters
+        # doesn't add a opk argument in here...
+        return [a for a in super().arguments if a.python_name == "input"]
+
     @async_safe
     def resolver(
         self,
@@ -275,7 +297,9 @@ class DjangoUpdateMutationField(DjangoInputMutationField):
         token = DjangoOptimizerExtension.enabled.set(False)
         try:
             instance = get_with_perms(pk, info, required=True, model=self.model)
-            return resolvers.update(info, instance, resolvers.parse_input(info, vdata))
+            return resolvers.update(
+                info, instance, resolvers.parse_input(info, vdata), full_clean=self.full_clean
+            )
         finally:
             DjangoOptimizerExtension.enabled.reset(token)
 
@@ -288,6 +312,12 @@ class DjangoDeleteMutationField(DjangoInputMutationField):
 
     """
 
+    @property
+    def arguments(self) -> List[StrawberryArgument]:
+        # FIXME: We don't have a base_resolve in this case. Make sure StrawberryDjangoFieldFilters
+        # doesn't add a opk argument in here...
+        return [a for a in super().arguments if a.python_name == "input"]
+
     @async_safe
     def resolver(
         self,
@@ -329,6 +359,7 @@ def mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> _T:
     ...
@@ -349,6 +380,7 @@ def mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> Any:
     ...
@@ -369,6 +401,7 @@ def mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> DjangoInputMutationField:
     ...
@@ -388,6 +421,7 @@ def mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
@@ -409,7 +443,7 @@ def mutation(
         python_name=None,
         django_name=field_name,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=StrawberryAnnotation.from_annotation(graphql_type),
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
@@ -443,6 +477,7 @@ def input_mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> _T:
     ...
@@ -464,6 +499,7 @@ def input_mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> Any:
     ...
@@ -485,6 +521,7 @@ def input_mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> DjangoInputMutationField:
     ...
@@ -505,6 +542,7 @@ def input_mutation(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
     # This init parameter is used by pyright to determine whether this field
     # is added in the constructor or not. It is not used to change
@@ -529,7 +567,7 @@ def input_mutation(
         python_name=None,
         django_name=field_name,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=StrawberryAnnotation.from_annotation(graphql_type),
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
@@ -561,7 +599,9 @@ def create(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
+    full_clean: bool = True,
 ) -> Any:
     """Create mutation for django input fields.
 
@@ -583,7 +623,7 @@ def create(
         python_name=None,
         django_name=field_name,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=StrawberryAnnotation.from_annotation(graphql_type),
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
@@ -594,6 +634,7 @@ def create(
         directives=directives,
         filters=filters,
         handle_django_errors=handle_django_errors,
+        full_clean=full_clean,
     )
 
 
@@ -612,7 +653,9 @@ def update(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
+    full_clean: bool = True,
 ) -> Any:
     """Update mutation for django input fields.
 
@@ -632,7 +675,7 @@ def update(
         python_name=None,
         django_name=field_name,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=StrawberryAnnotation.from_annotation(graphql_type),
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
@@ -643,6 +686,7 @@ def update(
         directives=directives,
         filters=filters,
         handle_django_errors=handle_django_errors,
+        full_clean=full_clean,
     )
 
 
@@ -661,6 +705,7 @@ def delete(
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     metadata: Optional[Mapping[Any, Any]] = None,
     directives: Optional[Sequence[object]] = (),
+    graphql_type: Optional[Any] = None,
     handle_django_errors: bool = True,
 ) -> Any:
     return DjangoDeleteMutationField(
@@ -668,7 +713,7 @@ def delete(
         python_name=None,
         django_name=field_name,
         graphql_name=name,
-        type_annotation=None,
+        type_annotation=StrawberryAnnotation.from_annotation(graphql_type),
         description=description,
         is_subscription=is_subscription,
         permission_classes=permission_classes or [],
